#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?tmpfiles_create:%global tmpfiles_create systemd-tmpfiles --create}
# baseversion - version of kubernetes for this package
%define baseversion 1.23
%define baseversionminus1 1.22

Name:           kubernetes%{baseversion}
Version:        1.23.17
Release:        5.3
Summary:        Container Scheduling and Management
License:        Apache-2.0
Group:          System/Management
URL:            https://kubernetes.io/
Source:         kubernetes-%{version}.tar.xz
Source2:        genmanpages.sh
Source3:        kubelet.sh
#systemd services
Source10:       kubelet.service
#config files
Source22:       sysconfig.kubelet-kubernetes
Source23:       kubeadm.conf
Source24:       90-kubeadm.conf
Source25:       10-kubeadm.conf
Source27:       kubelet.tmp.conf
Source28:       kubernetes-rpmlintrc
Source29:       kubernetes.obsinfo
# Patch to change the default registry to registry.opensuse.org/kubic
Patch2:         kubeadm-opensuse-registry.patch
# Patch to change the version check server to kubic.opensuse.org
Patch3:         opensuse-version-checks.patch
# Patch to change the default flexvolume path in kubeadm to match that used by our kubelet, else kubeadm tries to write to /usr when kubelet is already looking at a path on /var thanks to the fix to bsc#1084766
Patch4:         kubeadm-opensuse-flexvolume.patch
# Patch to revert renaming of coredns image location to match how it's done on download.opensuse.org
Patch5:         revert-coredns-image-renaming.patch
# Patch to fix CVE-2023-2727 and CVE-2023-2728, by preventing ephemeral containers from using an image that is restricted by ImagePolicyWebhook and from bypassing the mountable secrets policy enforced by the ServiceAccount admission plugin
Patch6:         kube-apiserver-admission-plugin-policy.patch
# Patch to fix CVE-2023-2431, to return error when a Pod or Container's SecurityContext has a localhost seccomp type but an empty localhostProfile field.
Patch7:         fix-seccomp-localhost-error-handling.patch
BuildRequires:  fdupes
BuildRequires:  git
BuildRequires:  go-go-md2man
BuildRequires:  golang-packaging
BuildRequires:  rsync
BuildRequires:  systemd-rpm-macros
BuildRequires:  golang(API) = 1.17
BuildRequires:  golang(github.com/jteeuwen/go-bindata)
ExcludeArch:    %{ix86} s390 ppc64

%description
Kubernetes is a system for automating deployment, scaling, and
management of containerized applications.

It groups containers that make up an application into logical units
for management and discovery.








# packages to build containerized control plane
%package apiserver
Summary:        Kubernetes apiserver for container image
Group:          System/Management
Provides:       kubernetes-apiserver-provider = %{version}
Conflicts:      kubernetes-apiserver-provider

%description apiserver
This subpackage contains the kube-apiserver binary for Kubic images

%package controller-manager
Summary:        Kubernetes controller-manager for container image
Group:          System/Management
Provides:       kubernetes-controller-manager-provider = %{version}
Conflicts:      kubernetes-controller-manager-provider

%description controller-manager
This subpackage contains the kube-controller-manager binary for Kubic images

%package scheduler
Summary:        Kubernetes scheduler for container image
Group:          System/Management
Provides:       kubernetes-scheduler-provider = %{version}
Conflicts:      kubernetes-scheduler-provider

%description scheduler
This subpackage contains the kube-scheduler binary for Kubic images

%package proxy
Summary:        Kubernetes proxy for container image
Group:          System/Management
Provides:       kubernetes-proxy-provider = %{version}
Conflicts:      kubernetes-proxy-provider
Requires:       conntrack-tools
Requires:       ebtables
Requires:       ipset
Requires:       iptables

%description proxy
This subpackage contains the kube-proxy binary for Kubic images

%package kubelet
Summary:        Kubernetes kubelet daemon
Group:          System/Management
Requires:       cri-runtime
Requires:       kubernetes-kubelet-common
Provides:       kubernetes-kubelet%{baseversion} = %{version}
Obsoletes:      kubernetes-kubelet%{baseversion} < %{version}
%{?systemd_requires}

%description kubelet
Manage a cluster of Linux containers as a single system to accelerate Dev and simplify Ops.
kubelet daemon (current version)

%package kubelet-common
Summary:        Kubernetes kubelet daemon
Group:          System/Management
Requires:       cri-runtime
Requires:       kubernetes-kubelet%{baseversion}
Provides:       kubernetes-kubelet-common = %{version}
Conflicts:      kubernetes-kubelet-common

%description kubelet-common
Manage a cluster of Linux containers as a single system to accelerate Dev and simplify Ops.
kubelet daemon

%package kubeadm
Summary:        Kubernetes kubeadm bootstrapping tool
Group:          System/Management
Provides:       kubernetes-kubeadm-provider = %{version}
Conflicts:      kubernetes-kubeadm-provider
Obsoletes:      kubernetes%{baseversionminus1}-kubeadm
Requires:       cri-runtime
Requires:       cri-tools
Requires:       ebtables
Requires:       ethtool
Requires:       kubernetes-kubeadm-criconfig
Requires:       socat
Requires(pre):  shadow
Requires:       (kubernetes%{baseversion}-kubelet or kubernetes%{baseversionminus1}-kubelet)

%description kubeadm
Manage a cluster of Linux containers as a single system to accelerate Dev and simplify Ops.
kubeadm bootstrapping tool

%package client
Summary:        Kubernetes client tools
Group:          System/Management
Provides:       kubernetes-client-provider = %{version}
Requires:       kubernetes-client-common >= %{version}
Requires(post): update-alternatives
Requires(postun):update-alternatives

%description client
Kubernetes client tools like kubectl.

%package client-common
Summary:        Kubernetes client tools common files
Group:          System/Management
Requires:       kubernetes%{baseversion}-client
Provides:       kubernetes-client-common = %{version}
Conflicts:      kubernetes-client-common
Obsoletes:      kubernetes%{baseversionminus1}-client-common
Recommends:     bash-completion

%description client-common
Kubernetes client tools common files

%package client-bash-completion
Summary:        Bash Completion for %{name}-client
Group:          System/Shells
BuildRequires:  bash-completion
Requires:       bash-completion
Requires:       kubernetes%{baseversion}-client = %{version}
Supplements:    (kubernetes%{baseversion}-client and bash-completion)
BuildArch:      noarch
Obsoletes:      kubernetes%{baseversionminus1}-client-bash-completion
Provides:       kubernetes-client-bash-completion = %{version}
Conflicts:      kubernetes-client-bash-completion
Conflicts:      kubernetes1.18-client-common

%description client-bash-completion
Bash command line completion support for %{name}-client

%package client-fish-completion
Summary:        Fish Completion for %{name}-client
Group:          System/Shells
BuildRequires:  fish
Requires:       kubernetes%{baseversion}-client = %{version}
Supplements:    (kubernetes%{baseversion}-client and fish)
BuildArch:      noarch
Obsoletes:      kubernetes%{baseversionminus1}-client-fish-completion
Provides:       kubernetes-client-fish-completion = %{version}
Conflicts:      kubernetes-client-fish-completion

%description client-fish-completion
Fish command line completion support for %{name}-client.

%prep
%setup -q -n kubernetes-%{version}
%patch2 -p1
%patch3 -p1
%patch4 -p0
%patch5 -p1
%patch6 -p1
%patch7 -p1

%build
# This is fixing bug bsc#1065972
export KUBE_GIT_COMMIT=$(grep "commit:" %{SOURCE29} | cut -d ":" -f2 | tr -d " ")
# KUBE_GIT_TREE_STATE="clean" indicates no changes since the git commit id
# KUBE_GIT_TREE_STATE="dirty" indicates source code changes after the git commit id
export KUBE_GIT_TREE_STATE="clean"
export KUBE_GIT_VERSION=v%{version}

# https://bugzilla.redhat.com/show_bug.cgi?id=1392922#c1
%ifarch ppc64le
export GOLDFLAGS='-linkmode=external'
%endif

#TEST
make WHAT="cmd/kube-apiserver cmd/kube-controller-manager cmd/kube-scheduler cmd/kube-proxy cmd/kubelet cmd/kubectl cmd/kubeadm" GOFLAGS="-buildmode=pie"

# The majority of the documentation has already been moved into
# http://kubernetes.io/docs/admin, and most of the files stored in the `docs`
# directory simply point there. That being said, some of the files are actual
# man pages, but they have to be generated with `hack/generate-docs.sh`. So,
# let's do that and run `genmanpages.sh`.
./hack/generate-docs.sh || true
pushd docs
pushd admin
cp kube-apiserver.md kube-controller-manager.md kube-proxy.md kube-scheduler.md kubelet.md ..
popd
cp %{SOURCE2} genmanpages.sh
bash genmanpages.sh
popd

%install

%ifarch ppc64le aarch64
output_path="_output/local/go/bin"
%else
output_path="_output/local/bin/linux/%{go_arch}"
%endif

install -m 755 -d %{buildroot}%{_bindir}

echo "+++ INSTALLING kubeadm"
install -p -m 755 -t %{buildroot}%{_bindir} ${output_path}/kubeadm

binaries=(kube-apiserver kube-controller-manager kube-scheduler kube-proxy)
for bin in "${binaries[@]}"; do
  echo "+++ INSTALLING ${bin}"
  install -p -m 755 -t %{buildroot}%{_bindir} ${output_path}/${bin}
done

for bin in kubelet kubectl; do
  echo "+++ INSTALLING ${bin} with %{baseversion} suffix"
  install -p -m 755 ${output_path}/${bin} %{buildroot}%{_bindir}/${bin}%{baseversion}
done

echo "+++ INSTALLING kubelet multi-version loader"
install -p -m 755 %{SOURCE3} %{buildroot}%{_bindir}/kubelet

# create sysconfig.kubelet-kubernetes in fullupdir
sed -i -e 's|BASE_VERSION|%{baseversion}|g' %{SOURCE22}
install -D -m 0644 %{SOURCE22} %{buildroot}%{_fillupdir}/sysconfig.kubelet-kubernetes%{baseversion}

# install the bash completion
install -d -m 0755 %{buildroot}%{_datadir}/bash-completion/completions/
%{buildroot}%{_bindir}/kubectl%{baseversion} completion bash > %{buildroot}%{_datadir}/bash-completion/completions/kubectl

# install the fish completion
mkdir -p %{buildroot}%{_datadir}/fish/vendor_completions.d
%{buildroot}%{_bindir}/kubectl%{baseversion} completion fish > %{buildroot}%{_datadir}/fish/vendor_completions.d/kubectl.fish

# move CHANGELOG-%{baseversion}.md to old location
mv CHANGELOG/CHANGELOG-%{baseversion}.md .

# cleanup before copying dirs...
rm -f hack/.linted_packages
find .    -name '.gitignore' -type f -delete
find hack -name '*.sh.orig' -type f -delete
find hack -name '.golint_*' -type f -delete

# systemd service
install -d -m 0755 %{buildroot}%{_unitdir}
install -m 0644 -t %{buildroot}%{_unitdir}/ %{SOURCE10}

# make symlinks to rc files
install -d -m 0755 %{buildroot}%{_sbindir}
ln -sf service "%{buildroot}%{_sbindir}/rckubelet"

# install manpages
install -d %{buildroot}%{_mandir}/man1
install -p -m 644 docs/man/man1/* %{buildroot}%{_mandir}/man1

# create config folder
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}

# manifests file for the kubelet
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}/manifests

# place kubernetes.tmp.conf to /usr/lib/tmpfiles.d/kubernetes.conf
install -d -m 0755 %{buildroot}%{_tmpfilesdir}
install -D -m 0644 %{SOURCE27} %{buildroot}/%{_tmpfilesdir}/kubelet.conf

# install the place the kubelet defaults to put volumes
install -d %{buildroot}%{_localstatedir}/lib/kubelet

%define volume_plugin_dir %{_localstatedir}/lib/kubelet/volume-plugin
install -d %{buildroot}/%{volume_plugin_dir}

# Add kubeadm modprobe.d and sysctl.d drop-in configs
mkdir -p %{buildroot}%{_prefix}/lib/modules-load.d
mkdir -p %{buildroot}%{_sysctldir}
install -m 0644 -t %{buildroot}%{_prefix}/lib/modules-load.d/ %{SOURCE23}
install -m 0644 -t %{buildroot}%{_sysctldir} %{SOURCE24}

# Create kubeadm systemd unit drop-in
install -d -m 0755 %{buildroot}%{_unitdir}/kubelet.service.d
sed -i -e 's|PATH_TO_FLEXVOLUME|%{volume_plugin_dir}|g' %{SOURCE25}
install -m 0644 -t %{buildroot}%{_unitdir}/kubelet.service.d/ %{SOURCE25}

# alternatives
ln -s -f %{_sysconfdir}/alternatives/kubectl %{buildroot}%{_bindir}/kubectl

%fdupes -s %{buildroot}

%post client-common
%{_sbindir}/update-alternatives \
  --install %{_bindir}/kubectl kubectl %{_bindir}/kubectl%{baseversion} %(echo %{baseversion} | tr -d .)

%postun client-common
if [ ! -f %{_bindir}/kubectl%{baseversion} ] ; then
  update-alternatives --remove kubectl %{_bindir}/kubectl%{baseversion}
fi

%pre kubelet-common
%service_add_pre kubelet.service

%post kubelet-common
%fillup_only -an kubelet
%service_add_post kubelet.service
%if 0%{?suse_version} < 1500
# create some subvolumes needed by CNI
if [ ! -e %{_localstatedir}/lib/cni ]; then
  if [ "`findmnt -o FSTYPE -l  /|grep -v FSTYPE`" = "btrfs" ]; then
    %{_sbindir}/mksubvolume %{_localstatedir}/lib/cni
  fi
fi
%endif
%tmpfiles_create %{_tmpfilesdir}/kubelet.conf

%preun kubelet-common
%service_del_preun kubelet.service

%postun kubelet-common
%service_del_postun kubelet.service

%files kubelet-common
%doc README.md CONTRIBUTING.md CHANGELOG-%{baseversion}.md
%license LICENSE
%{_mandir}/man1/kubelet.1%{?ext_man}
%{_bindir}/kubelet
%{_unitdir}/kubelet.service
%dir %{_unitdir}/kubelet.service.d
%{_sbindir}/rckubelet
%dir %{_localstatedir}/lib/kubelet
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/manifests
%{_tmpfilesdir}/kubelet.conf
%attr(0750,root,root) %dir %ghost %{_rundir}/%{name}
%dir %{volume_plugin_dir}
%{_fillupdir}/sysconfig.kubelet-kubernetes%{baseversion}

# openSUSE is using kubeadm with containerizied control plane, we
# only need the binaries

%files apiserver
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-apiserver.1%{?ext_man}
%{_bindir}/kube-apiserver

%files controller-manager
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-controller-manager.1%{?ext_man}
%{_bindir}/kube-controller-manager

%files scheduler
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-scheduler.1%{?ext_man}
%{_bindir}/kube-scheduler

%files proxy
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-proxy.1%{?ext_man}
%{_bindir}/kube-proxy

%files kubelet
%license LICENSE
%{_bindir}/kubelet%{baseversion}

%files kubeadm
%doc README.md CONTRIBUTING.md CHANGELOG-%{baseversion}.md
%{_unitdir}/kubelet.service.d/10-kubeadm.conf
%dir %{_prefix}/lib/modules-load.d
%{_prefix}/lib/modules-load.d/kubeadm.conf
%{_sysctldir}/90-kubeadm.conf
%license LICENSE
%{_bindir}/kubeadm
%{_mandir}/man1/kubeadm*

%files client
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_bindir}/kubectl
%{_bindir}/kubectl%{baseversion}
%ghost %_sysconfdir/alternatives/kubectl

%files client-common
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kubectl.1%{?ext_man}
%{_mandir}/man1/kubectl-*

%files client-bash-completion
%{_datadir}/bash-completion/completions/kubectl

%files client-fish-completion
%{_datadir}/fish/vendor_completions.d/kubectl.fish

%changelog
* Tue Jun 20 2023 Priyanka Saggu <priyanka.saggu@suse.com>
- Security Patch Fix for CVE-2023-2431 (bsc#1212493)
  * added patch: fix-seccomp-localhost-error-handling.patch
  * this new kubelet component patch returns an error when a Pod or Container's SecurityContext has a localhost seccomp type but an empty localhostProfile field.
* Thu Jun 15 2023 Priyanka Saggu <priyanka.saggu@suse.com>
- Security Patch Fix for CVE-2023-2727 (bsc#1211630) and CVE-2023-2728 (bsc#1211631)
  * added patch: kube-apiserver-admission-plugin-policy.patch
  * this new kube-apiserver component patch prevents ephemeral containers:
  * * from using an image that is restricted by ImagePolicyWebhook (CVE-2023-2727)
  * * from bypassing the mountable secrets policy enforced by the ServiceAccount admission plugin (CVE-2023-2728)
* Wed Apr 12 2023 Priyanka Saggu <priyanka.saggu@suse.com>
- add kubernetes1.18-client-common as conflicts with kubernetes-client-bash-completion
* Mon Mar 27 2023 Robert Munteanu <rombert@apache.org>
- Stronger conflicts for completion packages
* Mon Mar 27 2023 Robert Munteanu <rombert@apache.org>
- Split individual completions into separate packages
* Thu Mar  2 2023 Priyanka Saggu <priyanka.saggu@suse.com>
- update patch files to reflect upstream registry changes from k8s.gcr.io to registry.k8s.io
  * kubeadm-opensuse-registry.patch
  * revert-coredns-image-renaming.patch
* Thu Mar  2 2023 priyanka.saggu@suse.com
- Update to version 1.23.17:
  * Release commit for Kubernetes v1.23.17
  * releng: Update images, dependencies and version to Go 1.19.6
  * Update golang.org/x/net to v0.7.0
  * Pin golang.org/x/net to v0.4.0
  * add scale test for probes
  * use custom dialer for http probes
  * use custom dialer for tcp probes
  * add custom dialer optimized for probes
  * egress_selector: prevent goroutines leak on connect() step.
  * tls.Dial() validates hostname, no need to do that manually
  * Fix issue that Audit Server could not correctly encode DeleteOption
  * Do not include scheduler name in the preemption event message
  * Do not leak cross namespace pod metadata in preemption events
  * pkg/controller/job: re-honor exponential backoff
  * releng: Update images, dependencies and version to Go 1.19.5
  * Bump Konnectivity to v0.0.35
  * Improve vendor verification works for each staging repo
  * Update to go1.19
  * Adjust for os/exec changes in 1.19
  * Update golangci-lint to 1.46.2 and fix errors
  * Match go1.17 defaults for SHA-1 and GC
  * update golangci-lint to 1.45.0
  * kubelet: make the image pull time more accurate in event
  * change k8s.gcr.io/pause to registry.k8s.io/pause
  * use etcd 3.5.6-0 after promotion
  * changelog: CVE-2022-3294 and CVE-2022-3162 were fixed in v1.23.14
  * Add CVE-2021-25749 to CHANGELOG-1.23.md
  * Add CVE-2022-3294 to CHANGELOG-1.23.md
  * kubeadm: use registry.k8s.io instead of k8s.gcr.io
  * etcd: Updated to v3.5.5
  * Bump konnectivity network proxy to v0.0.33. Includes a couple bug fixes for better handling of dial failures. [Agent & Server](https://github.com/kubernetes-sigs/apiserver-network-proxy/commits/v0.0.33) include numerous other fixes.
  * kubeadm: allow RSA and ECDSA format keys in preflight check
  * Fixes kubelet log compression on Windows
  * Reduce default gzip compression level from 4 to 1 in apiserver
  * exec auth: support TLS config caching
  * Marshal MicroTime to json and proto at the same precision
  * Windows: ensure runAsNonRoot does case-insensitive comparison on user name
  * update structured-merge-diff to 4.2.3
  * Add rate limiting when calling STS assume role API
  * Fixing issue in generatePodSandboxWindowsConfig for hostProcess containers by where pod sandbox won't have HostProcess bit set if pod does not have a security context but containers specify HostProcess.
* Tue Jul 19 2022 jkowalczyk@suse.com
- Update to version 1.23.9:
  * Do not skip job requeue in conflict error
  * kubeadm: fix the bug that configurable KubernetesVersion not respected during kubeadm join
  * Bump cAdvisor to v0.43.1
  * Fix: filter out unsatisfied nodes when calling AddPod in PodTopologySpread
  * kubeadm: fix the bug that configurable KubernetesVersion not respected during kubeadm join
  * GIT-110239: fix activeDeadlineSeconds enforcement bug
  * fix: --chunk-size with selector returns missing result
  * Fixed winkernel proxy failing to query v1 endpoints created by dockershim CNIs
  * Winkernel proxier cache HNS data to improve syncProxyRules performance
  * Update CHANGELOG/CHANGELOG-1.23.md for v1.23.8
  * apiserver: printers should use int64
  * add missing error handling steps
  * add missing error handling steps
  * fix image pulling failure when IMDS is unavailalbe in kubelet startup
  * fix: exclude non-ready nodes and deleted nodes from azure load balancers
  * Avoid updating Services with stale specs Fix the bug that service specs in servicesToUpdate may have been updated by clients.
- Require only BuildRequires: golang(API) = 1.17 pinned Go major version.
  Remove potentially conflicting BuildRequires: go >= x.y.z.
  The plan for future updates is BuildRequires: golang(API) >= 1.17
  minimum Go major version.
* Tue Jul 19 2022 jkowalczyk@suse.com
- Update to version 1.23.8:
  * Revert "Automated cherry pick of #109124: Winkernel proxier cache HNS data to improve syncProxyRules"
  * test: update graceful node shutdown e2e with watch
  * move the ignore logic higher up to the reconciler
  * Ignore EndpointSlices that are already marked for deletion
  * kubelet: Mark ready condition as false explicitly for terminal pods
  * agnhost: bump version 2.39
  * Update Go to 1.17.11
  * add service e2e tests
  * kubelet: add e2e test to verify probe readiness
  * kubelet: only shutdown probes for pods that are terminated
  * kubelet: Pod probes should be handled by pod worker
  * Enable resize feature
  * Reject proxy requests to 0.0.0.0 as well
  * ipvs: fix prevent concurrent map read and map write for 1.23
  * cpu manager policy set to none, no one remove container id from container map, lead memory leak
  * fix audit union loop variables in closures
  * Updating e2e test to check EndpointSlices and Endpoints as well
  * e2e: services with evicted pods doesn't have endpoints
  * e2e test for evicted pods
  * endpoints controller: don't consider terminal endpoints
  * endpointslices: terminal pods doesn't receive enpoints
  * add pod util to verify pod is terminal
  * Update CHANGELOG/CHANGELOG-1.23.md for v1.23.7
  * Add test for checking ephemeral volume expansion
  * Fix resizing of ephemeral volumes
  * untangle fix with healthCheck feature
  * Winkernel proxier cache HNS data to improve syncProxyRules performance
  * Skip updating Endpoints and EndpointSlice if no relevant fields change
* Tue Jul 19 2022 jkowalczyk@suse.com
- Update to version 1.23.7:
  * Fix requests scope classification
  * Update Go to 1.17.10
  * authn: fix cache mutation by AuthenticatedGroupAdder
  * GCE: skip updating and deleting external loadbalancers if service is managed outside of service controller
  * Wait for cache to sync in job's TestWatchOrphanPods
  * Fix OpenAPI loading error caused by empty APIService
  * Test Foreground deletion in job integration
  * Fix removing finalizer from finished jobs
  * Don't mark job as failed until expectations are satisfied
  * Integration test for backoff limit and finalizers
  * component-base: replace url in rest client metrics
  * fix broken find command
  * Allow KUBE_TEST_REPO_LIST to be a remote url as well
  * Disable JobTrackingWithFinalizers due to unresolved bug
  * Update CHANGELOG/CHANGELOG-1.23.md for v1.23.6
  * Correct event registration for multiple scheduler plugins.
  * kubelet: rename closeAllConns to onHeartbeatFailure
  * kubelet apiserver: be gentle closing connections on heartbeat failures
  * fix: race detected in TestErrConnKilled
  * Replace hardcoded kubectl with kubectl.Name()
  * kubectl: fix hard-coded value in zsh completion
  * kubeadm: add etcd flag for member data consistency
  * Fix a bug that out-of-tree plugin is misplaced when using scheduler v1beta3 config
  * ipvs: remove port opener
  * iptables: remove port opener
  * azure_file: try to get secret namespace from ClaimRef
  * azure_file: add namespace tests for InTree to CSI conversion
* Tue Jul 19 2022 jkowalczyk@suse.com
- Update to version 1.23.6:
  * Update Go to 1.17.9
  * Fix: abort nominating a pod that was already scheduled to a node
  * Fix the overestimated cost of deletaged API requests in P&F
  * omit enums from static openapi snapshots used to generate clients
  * Drop enum tag from certificate request condition
  * Addresses the issue which caused #109115
  * Add test for indexer with multiple values
  * Reduce number of pods in Job+GC tests
  * Adjust validation checks to pass for both client-side and server-side validation
  * Remove finalizer when orphaned
  * Fix: Clean job tracking finalizer from orphan pods
  * Add test for Background delete propagation
  * Add integration test for orphan pods when there is GC
  * Copy request in timeout handler
  * kube-up: use registry.k8s.io for containerd-related jobs
  * kubelet: If the container status is created, we are waiting
  * e2e: Wait only for the service account
  * e2e: Wait for kube-root-ca.crt to be created
  * client-go: update generated
  * default kubernetes agent for generated clients
  * Include pod UID in secret/configmap cache key
  * Move kubelet secret and configmap manager calls to sync_Pod functions
  * test: Verify that nodes do not transition to Failed while ready
  * test: Add E2E for job completions with cpu reservation
  * test: Add E2E for init container pod deletion
  * kubelet: Delay writing a terminal phase until the pod is terminated
  * Update CHANGELOG/CHANGELOG-1.23.md for v1.23.5
  * generated: make update
  * polish comments of non-enum values.
  * unmark non-validated types as enums.
* Tue Jul 19 2022 jkowalczyk@suse.com
- Update to version 1.23.5:
  * Remove apf_fd from httplog
  * Update Go to 1.17.8
  * cluster/gce: update konnectivity image tags to v0.0.30
  * bump sigs.k8s.io/apiserver-network-proxy/konnectivity-client@v0.0.30
  * fix dryrun when ca file exists
  * fix regression introduced by PR 100320
  * Add unit tests
  * Fix nodes volumesAttached status not updated
  * Fix default config flags
  * test/e2e/framework: include the new control plane taint
  * kubelet: Clean up a static pod that has been terminated before starting
  * Add an e2e test for updating a static pod while it restarts
  * cronjob_controllerv2: do not filter jobs to be reconciled by labels
  * kube-proxy: fix duplicate port opening
  * increase Azure ACR credential provider timeout
  * Updating EndpointSlice strategy to retain node name in topology until field is set
  * fix: do not return early in the node informer when there is no change of the topology label.
  * /test/e2e_kubeadm: adjust label checks for 1.23
  * Ignore container notfound error while getPodstatuses
  * Update CHANGELOG/CHANGELOG-1.23.md for v1.23.4
  * Add PDB selector patch integration test
  * Revert v1beta1 PodDisruptionBudget select patchStrategy
  * test/e2e_kubeadm: fix matching UnversionedKubeletConfigMap defaults
  * kubeadm: fix the bug that 'kubeadm init --dry-run --upload-certs' command failed with 'secret not found' error
  * wrap error from RunCordonOrUncordon
* Wed Mar 16 2022 rbrown@suse.com
- Update to version 1.23.4:
  * Update Go to 1.17.7
  * Use serializable struct for x-kubernetes-validations in openapi
  * Make JSON schema round tripping test more strict
  * ignore CRI PodSandboxNetworkStatus for host network pods
  * set secondary address on host-network pods
  * Deeply copy JSONSchemaProps.XValidations.
  * Ensure the execHostnameTest() compares hostnames
  * Revert "Fix comparison between FQDN and hostname"
  * service REST: Call Decorator(old) on update path
  * add namespace in azurefile volumeid
  * fix: azurefile volumeid conflict in csi migration
  * Mark device as uncertain if unmount device succeeds
  * Update CHANGELOG/CHANGELOG-1.23.md for v1.23.3
  * kubelet: fix podstatus not containing pod full name
  * Fix bug with node restriction blocking pvc.status.resizestatus change
  * Fix regression pruning array fields with x-kubernetes-preserve-unknown-fields: true
  * Set max results if its not set
  * Update CHANGELOG/CHANGELOG-1.23.md for v1.23.2
  * Update k/utils to v0.0.0-20211116205334-6203023598ed
  * [go] update to Go 1.17.6
  * fix: remove outdated ipv4 route when the corresponding node is deleted
  * fix: delete non existing disk issue
  * Revert "Automated cherry pick of #107554: Correct the feature gate string for RBD migration."
  * fix containers order after applying
  * generated: ./hack/update-vendor.sh
  * upgrade sigs.k8s.io/structured-merge-diff/v4 to v4.2.1
  * Execute sync before taking the snapshot
  * Correct the feature gate string for RBD migration.
  * fix: azuredisk parameter lowercase translation issue
  * removed unnecessary log line
  * kubectl: add integration test for result reporting
  * cli: let kubectl handle error printing
  * cli: avoid logging command line errors in more cases
  * Fix header mutation race in timeout filter
  * clear pod's .status.nominatedNodeName when necessary
  * use node informer to check volumes attachment status before backoff
  * When volume is not marked in-use, do not backoff
  * kubeadm: remove the restriction that the ca.crt can only contain one certificate
  * flake fix: remove the error handler for cronjob integration test
  * Fix the leak of vSphere client sessions
  * fix nil pointer in create secret commands
  * Fix order of commands in the snapshot tests for persistent volumes
  * client-go: Clear the ResourceVersionMatch on paged list calls
  * Improving performance of EndpointSlice controller metrics cache
  * fix the error when cleaning up jobs for cronjob
  * Update CHANGELOG to add missing release notes.
  * apf: ensure exempt request notes the classification
  * Enabling kube-proxy metrics on windows kernel mode
  * Update CHANGELOG/CHANGELOG-1.23.md for v1.23.1
  * add gce loadbalancer no-op finalizer and existingFwdRule tests
  * disable gce service handling if has rbs forwarding rule
  * add ELBRbsFinalizer
  * add gce elb rbs opt-in annotation
  * cherry pick of knp 0.0.27
  * Remove JSON logging performance regression
  * Re-introduce removed kubectl --dry-run values.
  * Point flowcontrol users at v1beta2
  * [go1.17] Update to go1.17.5
  * dependencies: Update golang.org/x/net to v0.0.0-20211209124913-491a49abca63
  * mount-utils: Detect potential stale file handle
  * Skip creating HNS loadbalancer with empty endpoints
  * Add regression test for CPUManager distribute NUMA algorithm
  * Add unit test for CPUManager distribute NUMA algorithm verifying fixes
  * Fix accounting bug in CPUManager distribute NUMA policy
  * Fix error handling in CPUManager distribute NUMA tests
  * Add a sum() helper to the CPUManager cpuassignment logic
  * Allow the map.Values() function in the CPUManager to take a set of keys
  * Fix CPUManager algo to calculate min NUMA nodes needed for distribution
  * Fix unit tests following bug fix in CPUManager for map functions (2/2)
  * Fix unit tests following bug fix in CPUManager for map functions (1/2)
  * Fix bug in CPUManager map.Keys() and map.Values() implementations
  * Ensure we balance across *all* NUMA nodes in NUMA distribution algo
  * Short-circuit CPUManager distribute NUMA algo for unusable cpuGroupSize
  * Round the CPUManager mean and stddev calculations to the nearest 1000th
  * updated deprecation messages from 1.23 to 1.24
  * kubelet: set failed phase during graceful shutdown
  * kubeadm: avoid requiring a CA key during kubeconfig expiration checks
  * kubeadm: print the CA of kubeconfig files in "check expiration"
  * kubeadm: validate local etcd certficates during expiration checks
  * publishing-bot/doc: add component-helpers to the readme
  * publishing-bot/rules: remove non existing component-helpers branch 1.19 from the rules
  * Changelog: mention kube-scheduler bits deprication
  * rbd: initialize ceph monitors slice with an empty value.
  * Direct v2betaX users to migrate to HPA v2
  * DelegateFSGroupToCSIDriver e2e: skip tests with chgrp
  * Update CHANGELOG/CHANGELOG-1.23.md for v1.23.0
  * [go1.17] Update to go1.17.4
* Mon Feb  7 2022 Dirk Müller <dmueller@suse.com>
- avoid bashism in client-common postinstall script (bsc#1195391)
* Thu Jan 13 2022 Richard Brown <rbrown@suse.com>
- Increase _constraints to 13GB
* Thu Dec 16 2021 Richard Brown <rbrown@suse.com>
- Restore & rebase revert-coredns-image-renaming.patch from
  kubernetes1.22. Looks like it's still needed until all supported
  k8s versions allow us to change how we publish coredns containers
* Wed Dec  8 2021 Richard Brown <rbrown@suse.com>
- Initial Package
